# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/generated/inner/v1/app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/generated/inner/v1/app.proto',
  package='grebbleFlow.inner.v1',
  syntax='proto3',
  serialized_options=b'Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.grebble_flow/grpc/generated/inner/v1/app.proto\x12\x14grebbleFlow.inner.v1\"\x18\n\x16\x41ppExternalInfoRequest\"8\n\x13\x41ttributeSchemaItem\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xab\x01\n\x0f\x41ttributeSchema\x12?\n\x05items\x18\x01 \x03(\x0b\x32\x30.grebbleFlow.inner.v1.AttributeSchema.ItemsEntry\x1aW\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).grebbleFlow.inner.v1.AttributeSchemaItem:\x02\x38\x01\"e\n\x15ProcessorExternalInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x0f\x61ttributeSchema\x18\x02 \x01(\x0b\x32%.grebbleFlow.inner.v1.AttributeSchema\"Z\n\x17\x41ppInfoExternalResponse\x12?\n\nprocessors\x18\x01 \x03(\x0b\x32+.grebbleFlow.inner.v1.ProcessorExternalInfo2w\n\x0b\x45xternalApp\x12h\n\x07\x41ppInfo\x12,.grebbleFlow.inner.v1.AppExternalInfoRequest\x1a-.grebbleFlow.inner.v1.AppInfoExternalResponse\"\x00\x42:Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1b\x06proto3'
)




_APPEXTERNALINFOREQUEST = _descriptor.Descriptor(
  name='AppExternalInfoRequest',
  full_name='grebbleFlow.inner.v1.AppExternalInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=96,
)


_ATTRIBUTESCHEMAITEM = _descriptor.Descriptor(
  name='AttributeSchemaItem',
  full_name='grebbleFlow.inner.v1.AttributeSchemaItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='grebbleFlow.inner.v1.AttributeSchemaItem.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='grebbleFlow.inner.v1.AttributeSchemaItem.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=154,
)


_ATTRIBUTESCHEMA_ITEMSENTRY = _descriptor.Descriptor(
  name='ItemsEntry',
  full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=328,
)

_ATTRIBUTESCHEMA = _descriptor.Descriptor(
  name='AttributeSchema',
  full_name='grebbleFlow.inner.v1.AttributeSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='grebbleFlow.inner.v1.AttributeSchema.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTESCHEMA_ITEMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=328,
)


_PROCESSOREXTERNALINFO = _descriptor.Descriptor(
  name='ProcessorExternalInfo',
  full_name='grebbleFlow.inner.v1.ProcessorExternalInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.inner.v1.ProcessorExternalInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeSchema', full_name='grebbleFlow.inner.v1.ProcessorExternalInfo.attributeSchema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=431,
)


_APPINFOEXTERNALRESPONSE = _descriptor.Descriptor(
  name='AppInfoExternalResponse',
  full_name='grebbleFlow.inner.v1.AppInfoExternalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebbleFlow.inner.v1.AppInfoExternalResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=523,
)

_ATTRIBUTESCHEMA_ITEMSENTRY.fields_by_name['value'].message_type = _ATTRIBUTESCHEMAITEM
_ATTRIBUTESCHEMA_ITEMSENTRY.containing_type = _ATTRIBUTESCHEMA
_ATTRIBUTESCHEMA.fields_by_name['items'].message_type = _ATTRIBUTESCHEMA_ITEMSENTRY
_PROCESSOREXTERNALINFO.fields_by_name['attributeSchema'].message_type = _ATTRIBUTESCHEMA
_APPINFOEXTERNALRESPONSE.fields_by_name['processors'].message_type = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppExternalInfoRequest'] = _APPEXTERNALINFOREQUEST
DESCRIPTOR.message_types_by_name['AttributeSchemaItem'] = _ATTRIBUTESCHEMAITEM
DESCRIPTOR.message_types_by_name['AttributeSchema'] = _ATTRIBUTESCHEMA
DESCRIPTOR.message_types_by_name['ProcessorExternalInfo'] = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppInfoExternalResponse'] = _APPINFOEXTERNALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppExternalInfoRequest = _reflection.GeneratedProtocolMessageType('AppExternalInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPEXTERNALINFOREQUEST,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AppExternalInfoRequest)
  })
_sym_db.RegisterMessage(AppExternalInfoRequest)

AttributeSchemaItem = _reflection.GeneratedProtocolMessageType('AttributeSchemaItem', (_message.Message,), {
  'DESCRIPTOR' : _ATTRIBUTESCHEMAITEM,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchemaItem)
  })
_sym_db.RegisterMessage(AttributeSchemaItem)

AttributeSchema = _reflection.GeneratedProtocolMessageType('AttributeSchema', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTESCHEMA_ITEMSENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchema.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _ATTRIBUTESCHEMA,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchema)
  })
_sym_db.RegisterMessage(AttributeSchema)
_sym_db.RegisterMessage(AttributeSchema.ItemsEntry)

ProcessorExternalInfo = _reflection.GeneratedProtocolMessageType('ProcessorExternalInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSOREXTERNALINFO,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.ProcessorExternalInfo)
  })
_sym_db.RegisterMessage(ProcessorExternalInfo)

AppInfoExternalResponse = _reflection.GeneratedProtocolMessageType('AppInfoExternalResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPINFOEXTERNALRESPONSE,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AppInfoExternalResponse)
  })
_sym_db.RegisterMessage(AppInfoExternalResponse)


DESCRIPTOR._options = None
_ATTRIBUTESCHEMA_ITEMSENTRY._options = None

_EXTERNALAPP = _descriptor.ServiceDescriptor(
  name='ExternalApp',
  full_name='grebbleFlow.inner.v1.ExternalApp',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=525,
  serialized_end=644,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppInfo',
    full_name='grebbleFlow.inner.v1.ExternalApp.AppInfo',
    index=0,
    containing_service=None,
    input_type=_APPEXTERNALINFOREQUEST,
    output_type=_APPINFOEXTERNALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALAPP)

DESCRIPTOR.services_by_name['ExternalApp'] = _EXTERNALAPP

# @@protoc_insertion_point(module_scope)



import logging
from concurrent import futures

import grpc
from grebble_flow.grpc.generated.inner.v1 import processor_pb2_grpc, app_pb2_grpc
from grebble_flow.grpc.service.app import AppService
from grebble_flow.grpc.service.processor import ProcessorService


def start_server(port):
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    processor_pb2_grpc.add_ProcessorServicer_to_server(ProcessorService(), server)
    app_pb2_grpc.add_ExternalAppServicer_to_server(AppService(), server)
    server.add_insecure_port(f"[::]:{port}")
    server.start()
    logging.info("Server started")
    server.wait_for_termination()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/generated/inner/v1/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/generated/inner/v1/processor.proto',
  package='grebbleFlow.inner.v1',
  syntax='proto3',
  serialized_options=b'Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4grebble_flow/grpc/generated/inner/v1/processor.proto\x12\x14grebbleFlow.inner.v1\"\xb8\x01\n\x12\x46lowExecuteRequest\x12\x10\n\x08\x66lowName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12L\n\nattributes\x18\x03 \x03(\x0b\x32\x38.grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x01\n\x13\x46lowExecuteResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12M\n\nattributes\x18\x02 \x03(\x0b\x32\x39.grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry\x12\x10\n\x08mimeType\x18\x03 \x01(\t\x12\x11\n\tstreamEnd\x18\x04 \x01(\x08\x12\x0e\n\x06\x63ommit\x18\x05 \x01(\x08\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32o\n\tProcessor\x12\x62\n\x07\x45xecute\x12(.grebbleFlow.inner.v1.FlowExecuteRequest\x1a).grebbleFlow.inner.v1.FlowExecuteResponse\"\x00\x30\x01\x42:Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1b\x06proto3'
)




_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=263,
)

_FLOWEXECUTEREQUEST = _descriptor.Descriptor(
  name='FlowExecuteRequest',
  full_name='grebbleFlow.inner.v1.FlowExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowName', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.flowName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=263,
)


_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=263,
)

_FLOWEXECUTERESPONSE = _descriptor.Descriptor(
  name='FlowExecuteResponse',
  full_name='grebbleFlow.inner.v1.FlowExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mimeType', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.mimeType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamEnd', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.streamEnd', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.commit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=487,
)

_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY.containing_type = _FLOWEXECUTEREQUEST
_FLOWEXECUTEREQUEST.fields_by_name['attributes'].message_type = _FLOWEXECUTEREQUEST_ATTRIBUTESENTRY
_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY.containing_type = _FLOWEXECUTERESPONSE
_FLOWEXECUTERESPONSE.fields_by_name['attributes'].message_type = _FLOWEXECUTERESPONSE_ATTRIBUTESENTRY
DESCRIPTOR.message_types_by_name['FlowExecuteRequest'] = _FLOWEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['FlowExecuteResponse'] = _FLOWEXECUTERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowExecuteRequest = _reflection.GeneratedProtocolMessageType('FlowExecuteRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWEXECUTEREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _FLOWEXECUTEREQUEST,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteRequest)
  })
_sym_db.RegisterMessage(FlowExecuteRequest)
_sym_db.RegisterMessage(FlowExecuteRequest.AttributesEntry)

FlowExecuteResponse = _reflection.GeneratedProtocolMessageType('FlowExecuteResponse', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWEXECUTERESPONSE_ATTRIBUTESENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _FLOWEXECUTERESPONSE,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteResponse)
  })
_sym_db.RegisterMessage(FlowExecuteResponse)
_sym_db.RegisterMessage(FlowExecuteResponse.AttributesEntry)


DESCRIPTOR._options = None
_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY._options = None
_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY._options = None

_PROCESSOR = _descriptor.ServiceDescriptor(
  name='Processor',
  full_name='grebbleFlow.inner.v1.Processor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=489,
  serialized_end=600,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='grebbleFlow.inner.v1.Processor.Execute',
    index=0,
    containing_service=None,
    input_type=_FLOWEXECUTEREQUEST,
    output_type=_FLOWEXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSOR)

DESCRIPTOR.services_by_name['Processor'] = _PROCESSOR

# @@protoc_insertion_point(module_scope)



import os
from pathlib import Path

import pkg_resources


def install_proto():
    import grpc_tools.protoc

    proto_include = pkg_resources.resource_filename("grebble_flow", "proto")
    for file in [
        "grebble_flow/grpc/generated/inner/v1/app.proto",
        "grebble_flow/grpc/generated/inner/v1/processor.proto",
    ]:
        grpc_tools.protoc.main(
            [
                "grpc_tools.protoc",
                f"-I {proto_include}",
                f"--proto_path={proto_include}",
                f"--python_out=./",
                f"--grpc_python_out=./",
                f"{file}",
            ]
        )



from typing import Any


class FlowResponse:
    attributes: dict
    content: Any

    def __init__(self, attributes: dict, content: Any):
        self.attributes = attributes
        self.content = content


class BaseFlowProcessor(object):
    is_flow_processor = True

    def initialize(self, *args, **kwargs):
        raise NotImplemented()

    def execute(self, *args, **kwargs) -> FlowResponse:
        raise NotImplemented()



import json

from grebble_flow.grpc.generated.inner.v1.app_pb2 import (
    AppInfoExternalResponse,
    ProcessorExternalInfo,
    AttributeSchema,
    AttributeSchemaItem,
)
from grebble_flow.grpc.generated.inner.v1.app_pb2_grpc import ExternalAppServicer
from grebble_flow.managment.info import generate_package_info


class AppService(ExternalAppServicer):
    def __init__(self, *args, **kwargs):
        pass

    def AppInfo(self, request, context):
        info = generate_package_info()

        result = AppInfoExternalResponse()
        processors = list()
        for processor in info["processors"]:
            info = ProcessorExternalInfo(
                name=processor["name"], attributeSchema=AttributeSchema()
            )
            for key, value in processor["attributes_schema"].items():
                info.attributeSchema.items[key].CopyFrom(
                    AttributeSchemaItem(
                        type=value["type"], description=value["description"]
                    )
                )
            processors += [info]
        result.processors.extend(processors)
        return result
